pub struct ThreadControllerImpl { /* private fields */ }Expand description
Thread controller implementation.
This is the main implementation of the ThreadController trait.
It manages device threads and provides methods for device operations.
Thread controller implementation.
This is the main implementation of the ThreadController trait.
It manages device threads and provides methods for device operations.
Implementations
Sourceimpl ThreadControllerImpl
impl ThreadControllerImpl
Sourcepub fn with_logger(logger: Arc<dyn Logger>) -> Self
pub fn with_logger(logger: Arc<dyn Logger>) -> Self
Sourcepub fn set_default_refresh_interval(&mut self, interval_ms: u64)
pub fn set_default_refresh_interval(&mut self, interval_ms: u64)
Sourcepub fn set_logger(&mut self, logger: Arc<dyn Logger>)
pub fn set_logger(&mut self, logger: Arc<dyn Logger>)