pub struct DeviceState {
pub device_info: DeviceInfo,
pub device_data: DeviceData,
pub model: Option<DeviceModel>,
pub pins: Vec<PinData>,
pub encoders: Vec<EncoderData>,
pub pwm: PwmData,
pub last_update: u64,
pub status: ThreadStatus,
pub error_message: Option<String>,
pub custom_values: HashMap<String, String>,
}Expand description
Device state that is shared between threads.
This struct contains all the state information for a device, including device information, pin data, encoder data, and PWM data.
Fields
device_info: DeviceInfoDevice information
device_data: DeviceDataDevice data
model: Option<DeviceModel>Device model
pins: Vec<PinData>Pin data
encoders: Vec<EncoderData>Encoder data
pwm: PwmDataPWM data
last_update: u64Last update timestamp
status: ThreadStatusThread status
error_message: Option<String>Error message if any
custom_values: HashMap<String, String>Custom state values
Implementations
Sourceimpl DeviceState
impl DeviceState
Sourcepub fn new(device_info: DeviceInfo, device_data: DeviceData) -> Self
pub fn new(device_info: DeviceInfo, device_data: DeviceData) -> Self
Sourcepub fn update_from_device(&mut self, device: &PoKeysDevice)
pub fn update_from_device(&mut self, device: &PoKeysDevice)
Sourcepub fn get_digital_input(&self, pin: u32) -> Option<bool>
pub fn get_digital_input(&self, pin: u32) -> Option<bool>
Sourcepub fn get_analog_input(&self, pin: u32) -> Option<u32>
pub fn get_analog_input(&self, pin: u32) -> Option<u32>
Sourcepub fn get_encoder_value(&self, encoder_index: u32) -> Option<i32>
pub fn get_encoder_value(&self, encoder_index: u32) -> Option<i32>